@@ -63,6 +63,8 @@ MainWindow::MainWindow(QWidget *parent):
     //Initial QSettings for Spin Box
     initialpsb();
 
+    //Check for existance of /tmp/flopswapint to disable pushButton
+    disableStatus();
 }
 
 MainWindow::~MainWindow()
@@ -175,6 +177,45 @@ void MainWindow::initialseen()
 }
 
 
+//Eject Warning Text
+void MainWindow::ejectshow()
+{
+   QSettings settings("flopswap", "flopswap");
+
+   if (!settings.contains("EjectWarningShown"))
+       {
+        QMaemo5InformationBox::information(
+          0,
+          " <br> \
+            <br> \
+          This is the Swap to Device Button<br> \
+          This button will move your swap to the device to allow you to remove the back cover and/or uSD card. <br> \
+          CAUTION:- While swap is on the uSD DO NOT remove the back cover. <br> \
+          This will cause the device to reboot and may cause data loss or damage. <br> \
+          Please wait for the Safe to Remove Back Cover message. <br> \
+            <br> ",
+          0);
+       }
+}
+
+//Eject Warning Seen
+void MainWindow::ejectseen()
+{
+    QSettings settings("flopswap", "flopswap");
+
+    if (!settings.contains("EjectWarningShown"))
+        {
+         settings.setValue("EjectWarningShown", true);
+        }
+}
+
+//Check for existance of /tmp/flopswapint for pushButton
+void MainWindow::disableStatus()
+{
+ if ( QFileInfo("/tmp/flopswapint").exists() )
+     ui->pushButtonSwapUsage->setDisabled(true);
+}
+
 //Initial QSettings for Spin Box
 void MainWindow::initialpsb()
 {
@@ -190,21 +231,26 @@ void MainWindow::initialpsb()
 void MainWindow::on_pushButtonSwap_clicked()
 { 
     m_process->start("sudo /opt/flopswap/script/swapswitch.sh");
+    disableStatus();
 }
 
 void MainWindow::on_pushButtonEject_clicked()
 {
+    ejectshow();
     m_process->start("sudo /opt/flopswap/script/swapswitchejectsd.sh");
+    disableStatus();
 }
 
 void MainWindow::on_pushButtonGet_clicked()
 {
     m_process->start("sudo /opt/flopswap/script/catprocswap.sh");
+    disableStatus();
 }
 
 void MainWindow::on_pushButtonSwapUsage_clicked()
 {
     m_process->start("sudo /opt/flopswap/script/swapused.sh");
+    disableStatus();
 }
 
 //Actions
